naturf package
==============

Submodules
----------

naturf.model module
-------------------

.. automodule:: naturf.model
   :members:
   :undoc-members:
   :show-inheritance:

naturf.params module
--------------------

.. automodule:: naturf.params
   :members:
   :undoc-members:
   :show-inheritance:

naturf.utils module
-------------------

.. automodule:: naturf.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: naturf
   :members:
   :undoc-members:
   :show-inheritance:
